<?php
namespace ServerTasticToken;

use WHMCS\Database\Capsule;

class Helper
{
    public static function customFieldExists($relid, $name)
    {
        $name = (strpos($name, '|') ? $name . '|%' : $name . '%');        
        return Capsule::table('tblcustomfields')->where('relid', $relid)->where('type', 'product')->whereRaw('fieldname LIKE \'' . $name . '\'')->exists();
    }
    
    public static function getServerTasticOrders($name = 'token')
    {
        $name = (strpos($name, '|') ? $name . '|%' : $name . '%'); 
        return Capsule::table('tblorders AS to')
                ->select(
                        'th.id AS service_id', 
                        'tcfv.value AS order_token', 
                        'tp.configoption1 AS api_key' ,
                        'tp.configoption3 AS test_mode',
                        'tp.id AS product_id',
                        'to.userid AS client_id'
                        )
                ->join('tblhosting AS th', 'th.orderid', '=', 'to.id')
                ->join('tblproducts AS tp', 'tp.id', '=', 'th.packageid')
                ->join('tblcustomfields as tcf', 'tcf.relid', '=', 'tp.id')
                ->join('tblcustomfieldsvalues AS tcfv', 'tcfv.relid', '=', 'th.id')  
                ->where('tcfv.value', '<>', '')        
                ->where('to.status', 'Active')
                ->where('tcf.type','=', 'product') 
                ->where('tcf.fieldname', 'LIKE', $name)
                ->where('tp.servertype', '=', 'serverTasticToken') 
                ->get();
    }
    
    public static function createTokenCustomField($relid)
    {
        Capsule::table('tblcustomfields')->insert(array(
            'type' => 'product',
            'relid' => $relid,
            'fieldname' => 'token|Order Token',
            'fieldtype' => 'text',
            'adminonly' => 'on',
            'sortorder' => 0,
        ));
    }

    public static function addCustomFieldValue($fieldname, $relid, $serviceid, $value)
    {
        $like = strpos($fieldname, '|') ? $fieldname . '|%' : $fieldname . '%';
        $field = Capsule::table('tblcustomfields')->where('type', 'Product')->where('relid', $relid)->whereRaw('fieldname LIKE \'' . $like . '\'')->first()->id;
        Capsule::table('tblcustomfieldsvalues')->where('fieldid', $field)->where('relid', $serviceid)->delete();
        Capsule::table('tblcustomfieldsvalues')->insert(array(
            'fieldid' => $field,
            'relid' => $serviceid,
            'value' => $value,
        ));
    }

    const TEMPLATE_NAME = 'Certificate Activation Token';
    const CERT_EXPIRATION_TEMPLATE_NAME = 'Certificate Expiration Reminder';
    
    public static function emailTemplateExists()
    {
        return [
            self::TEMPLATE_NAME => Capsule::table('tblemailtemplates')->where('name', self::TEMPLATE_NAME)->exists(),
            self::CERT_EXPIRATION_TEMPLATE_NAME => Capsule::table('tblemailtemplates')->where('name', self::CERT_EXPIRATION_TEMPLATE_NAME)->exists(),
        ];
    }

    public static function createEmailTemplate()
    {
        Capsule::table('tblemailtemplates')->insert(array(
            'type' => 'product',
            'name' => self::TEMPLATE_NAME,
            'subject' => 'Your Certificate Token',
            'message' => "<p>You have successfully ordered Certificate Token</p><p>Your Token: {\$token}</p>",
        ));
    }
    
    public static function createCertExpirationEmailTemplate()
    {
        Capsule::table('tblemailtemplates')->insert(array(
            'type' => 'product',
            'name' => self::CERT_EXPIRATION_TEMPLATE_NAME,
            'subject' => 'Certificate Expiration Remind',
            'message' => "<p>Dear {\$client_name},</p><p>Your certificate will expire on {\$expiration_date}</p><p>You can renew the certificate at the link below:</p><p><a href=\"{\$token_order_url}\">{\$token_order_url}</a></p><p>Product/Service: {\$service_product_name}</p><p>ID: {\$service_id}</p>",
        ));
    }
}
